<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation>Autostatus Datei</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n Sekunde</numerusform><numerusform>%n Sekunden</numerusform></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Online</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäfigt</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Unsichtbar</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation>AutoStatus</translation>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation>$Autostatus</translation>
    </message>
</context>
</TS>